[llvm-commits] CVS: llvm/lib/Target/TargetMachine.cpp

Chris Lattner lattner at cs.uiuc.edu
Sat Dec 28 20:51:10 PST 2002


Changes in directory llvm/lib/Target:

TargetMachine.cpp updated: 1.16 -> 1.17

---
Log message:

Rename MachineOptInfo to TargetoptInfo
Rename MachineCacheInfo to TargetCacheInfo



---
Diffs of the changes:

Index: llvm/lib/Target/TargetMachine.cpp
diff -u llvm/lib/Target/TargetMachine.cpp:1.16 llvm/lib/Target/TargetMachine.cpp:1.17
--- llvm/lib/Target/TargetMachine.cpp:1.16	Tue Oct 29 15:47:50 2002
+++ llvm/lib/Target/TargetMachine.cpp	Sat Dec 28 20:50:31 2002
@@ -1,12 +1,12 @@
 //===-- TargetMachine.cpp - General Target Information ---------------------==//
 //
 // This file describes the general parts of a Target machine.
 // This file also implements MachineCacheInfo.
 //
 //===----------------------------------------------------------------------===//
 
 #include "llvm/Target/TargetMachine.h"
-#include "llvm/Target/MachineCacheInfo.h"
+#include "llvm/Target/TargetCacheInfo.h"
 #include "llvm/Type.h"
 
 //---------------------------------------------------------------------------
@@ -36,13 +36,13 @@
 
 
 //---------------------------------------------------------------------------
-// class MachineCacheInfo 
+// class TargetCacheInfo 
 // 
 // Purpose:
 //   Describes properties of the target cache architecture.
 //---------------------------------------------------------------------------
 
-void MachineCacheInfo::Initialize() {
+void TargetCacheInfo::Initialize() {
   numLevels = 2;
   cacheLineSizes.push_back(16);  cacheLineSizes.push_back(32); 
   cacheSizes.push_back(1 << 15); cacheSizes.push_back(1 << 20);
@@ -1,12 +1,12 @@
 //
 // This file describes the general parts of a Target machine.
-// This file also implements MachineCacheInfo.
+// This file also implements TargetCacheInfo.
 //
 //===----------------------------------------------------------------------===//





More information about the llvm-commits mailing list